@@ -8,6 +8,7 @@ describe 'nova::keystone::auth' do
 
   let :default_params do
     { :auth_name              => 'nova',
+      :service_name           => 'nova',
       :region                 => 'RegionOne',
       :tenant                 => 'services',
       :email                  => 'nova@localhost',
@@ -57,7 +58,7 @@ describe 'nova::keystone::auth' do
       :roles  => ['admin']
     )}
 
-    it { is_expected.to contain_keystone_service('foo::compute').with(
+    it { is_expected.to contain_keystone_service('nova::compute').with(
       :ensure      => 'present',
       :description => 'Openstack Compute Service'
     )}
@@ -123,12 +124,18 @@ describe 'nova::keystone::auth' do
 
   describe 'when configuring nova-api and the keystone endpoint' do
     let :pre_condition do
-      "class { 'nova::api': admin_password => 'test' }
-      include nova"
+      "class { '::nova::keystone::authtoken':
+         password => 'secrete',
+       }
+       class { 'nova::api':}
+       include nova"
     end
 
     let :facts do
-      @default_facts.merge({ :osfamily => "Debian"})
+      @default_facts.merge({
+        :osfamily => "Debian",
+        :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
+      })
     end
 
     let :params do
@@ -157,4 +164,3 @@ describe 'nova::keystone::auth' do
   end
 
 end
-
