@@ -23,7 +23,7 @@ require 'spec_helper'
 describe 'nova::migration::libvirt' do
 
   generate = {}
-
+  # needed for Puppet 4.x
   before(:each) {
     Puppet::Parser::Functions.newfunction(:generate, :type => :rvalue) {
         |args| generate.call()
@@ -31,8 +31,10 @@ describe 'nova::migration::libvirt' do
     generate.stubs(:call).returns('0000-111-111')
   }
 
+  # function here is needed for Puppet 5.5.7+
   let :pre_condition do
-   'include nova
+   'function generate($a, $b) { return "0000-111-111" }
+    include nova
     include nova::compute
     include nova::compute::libvirt'
   end
@@ -48,7 +50,6 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('<SERVICE DEFAULT>')}
     end
 
     context 'with override_uuid enabled' do
@@ -68,21 +69,6 @@ describe 'nova::migration::libvirt' do
       }).that_requires('Package[libvirt]').that_notifies('Service[libvirt]') }
     end
 
-    context 'with tls enabled (legacy)' do
-      let :params do
-        {
-          :use_tls => true,
-        }
-      end
-      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
-      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
-      it { is_expected.to contain_libvirtd_config('auth_tls').with_value("\"none\"") }
-      it { is_expected.not_to contain_libvirtd_config('auth_tcp') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
-      it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('<SERVICE DEFAULT>')}
-    end
-
     context 'with tls enabled' do
       let :params do
         {
@@ -107,9 +93,8 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value("\"none\"") }
       it { is_expected.not_to contain_libvirtd_config('auth_tcp') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('host1.example.com')}
-      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('tls')}
     end
 
     context 'with migration flags set' do
@@ -256,7 +241,7 @@ describe 'nova::migration::libvirt' do
     end
 
     it_configures 'nova migration with libvirt'
-    it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => 'libvirtd_opts="-d -l"') }
+    it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => 'libvirtd_opts="-l"') }
   end
 
   context 'on RedHat platforms' do
