@@ -8,7 +8,6 @@ describe 'nova::scheduler' do
 
   shared_examples 'nova-scheduler' do
 
-
     it { is_expected.to contain_package('nova-scheduler').with(
       :name   => platform_params[:scheduler_package_name],
       :ensure => 'present'
@@ -20,8 +19,9 @@ describe 'nova::scheduler' do
       :ensure    => 'running'
     )}
 
-    it { is_expected.to contain_nova_config('DEFAULT/scheduler_driver').with_ensure('absent') }
+    it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
     it { is_expected.to contain_nova_config('scheduler/driver').with_value('filter_scheduler') }
+    it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
 
     context 'with manage_service as false' do
       let :params do
@@ -42,6 +42,14 @@ describe 'nova::scheduler' do
       )}
     end
 
+    context 'with workers' do
+      let :params do
+        { :workers => 8 }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/workers').with_value(8) }
+    end
+
     context 'with scheduler driver' do
       let :params do
         { :scheduler_driver => 'custom driver' }
@@ -50,6 +58,14 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/driver').with_value('custom driver') }
     end
 
+    context 'with discover_hosts_in_cells_interval' do
+      let :params do
+        { :discover_hosts_in_cells_interval => 15 }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value(15) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
         "include nova"
@@ -81,7 +97,7 @@ describe 'nova::scheduler' do
 
   context 'on Debian platforms' do
     let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+      @default_facts.merge({ :osfamily => 'Debian', :os_workers => 4 })
     end
 
     let :platform_params do
@@ -94,7 +110,7 @@ describe 'nova::scheduler' do
 
   context 'on Redhat platforms' do
     let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
+      @default_facts.merge({ :osfamily => 'RedHat', :os_workers => 4 })
     end
 
     let :platform_params do
